Exception: SimplePolygons::InvalidLocationArrayError
- Inherits:
-
PolygonError
- Object
- StandardError
- PolygonError
- SimplePolygons::InvalidLocationArrayError
- Defined in:
- lib/simple-polygons.rb
Overview
Raised when an array of locations passed to a polygon constructor cannot form the specified type of polygon.